shithub: freetype+ttf2subf

Download patch

ref: 5f0ee94c06156e1c0d45c6add8a8716262c866d4
parent: 558ac99de1081f74842cc343133ae62d56054bf6
author: Werner Lemberg <[email protected]>
date: Tue Apr 30 02:37:52 EDT 2002

`interface' is reserved on the Mac.

* include/freetype/ftoutln.h, include/freetype/internal/sfnt.h,
src/base/ftoutln.c: s/interface/func_interface/.
* src/base/ftbbox.c (FT_Outline_Get_BBox):
s/interface/bbox_interface/.
* src/cff/cffdrivr.c: s/interface/module_interface/.
* src/cff/cffload.c, src/cff/cffload.h:
s/interface/psnames_interface/.
* src/cid/cidriver.c: s/interface/cid_interface/.
* src/sfnt/sfdriver.c: s/interface/module_interface/.
* src/smooth/ftgrays.c: s/interface/func_interface/.
* src/truetype/ttdriver.c: s/interface/tt_interface/.
* src/type1/t1driver.c: s/interface/t1_interface/.

git/fs: mount .git/fs: mount/attach disallowed
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,20 @@
+2002-04-30  Werner Lemberg  <[email protected]>
+
+	`interface' is reserved on the Mac.
+
+	* include/freetype/ftoutln.h, include/freetype/internal/sfnt.h,
+	src/base/ftoutln.c: s/interface/func_interface/.
+	* src/base/ftbbox.c (FT_Outline_Get_BBox):
+	s/interface/bbox_interface/.
+	* src/cff/cffdrivr.c: s/interface/module_interface/.
+	* src/cff/cffload.c, src/cff/cffload.h:
+	s/interface/psnames_interface/.
+	* src/cid/cidriver.c: s/interface/cid_interface/.
+	* src/sfnt/sfdriver.c: s/interface/module_interface/.
+	* src/smooth/ftgrays.c: s/interface/func_interface/.
+	* src/truetype/ttdriver.c: s/interface/tt_interface/.
+	* src/type1/t1driver.c: s/interface/t1_interface/.
+
 2002-04-29  Jouk Jansen  <[email protected]>
 
 	* descrip.mms (all): Add pfr driver.
--- a/include/freetype/internal/sfnt.h
+++ b/include/freetype/internal/sfnt.h
@@ -127,7 +127,7 @@
 
   typedef FT_Module_Interface
   (*SFNT_Get_Interface_Func)( FT_Module    module,
-                              const char*  interface );
+                              const char*  func_interface );
 
 
   /*************************************************************************/
--- a/src/base/ftbbox.c
+++ b/src/base/ftbbox.c
@@ -4,7 +4,7 @@
 /*                                                                         */
 /*    FreeType bbox computation (body).                                    */
 /*                                                                         */
-/*  Copyright 1996-2001 by                                                 */
+/*  Copyright 1996-2001, 2002 by                                           */
 /*  David Turner, Robert Wilhelm, and Werner Lemberg.                      */
 /*                                                                         */
 /*  This file is part of the FreeType project, and may only be used        */
@@ -622,7 +622,7 @@
       /* the two boxes are different, now walk over the outline to */
       /* get the Bezier arc extrema.                               */
 
-      static const FT_Outline_Funcs  interface =
+      static const FT_Outline_Funcs  bbox_interface =
       {
         (FT_Outline_MoveTo_Func) BBox_Move_To,
         (FT_Outline_LineTo_Func) BBox_Move_To,
@@ -637,7 +637,7 @@
 
       user.bbox = bbox;
 
-      error = FT_Outline_Decompose( outline, &interface, &user );
+      error = FT_Outline_Decompose( outline, &bbox_interface, &user );
       if ( error )
         return error;
 
--- a/src/base/ftoutln.c
+++ b/src/base/ftoutln.c
@@ -46,7 +46,7 @@
 
   FT_EXPORT_DEF( FT_Error )
   FT_Outline_Decompose( FT_Outline*              outline,
-                        const FT_Outline_Funcs*  interface,
+                        const FT_Outline_Funcs*  func_interface,
                         void*                    user )
   {
 #undef SCALED
@@ -70,11 +70,11 @@
     FT_Pos   delta;
 
 
-    if ( !outline || !interface )
+    if ( !outline || !func_interface )
       return FT_Err_Invalid_Argument;
 
-    shift = interface->shift;
-    delta = interface->delta;
+    shift = func_interface->shift;
+    delta = func_interface->delta;
     first = 0;
 
     for ( n = 0; n < outline->n_contours; n++ )
@@ -125,7 +125,7 @@
         tags--;
       }
 
-      error = interface->move_to( &v_start, user );
+      error = func_interface->move_to( &v_start, user );
       if ( error )
         goto Exit;
 
@@ -145,7 +145,7 @@
             vec.x = SCALED( point->x );
             vec.y = SCALED( point->y );
 
-            error = interface->line_to( &vec, user );
+            error = func_interface->line_to( &vec, user );
             if ( error )
               goto Exit;
             continue;
@@ -171,7 +171,7 @@
 
             if ( tag == FT_Curve_Tag_On )
             {
-              error = interface->conic_to( &v_control, &vec, user );
+              error = func_interface->conic_to( &v_control, &vec, user );
               if ( error )
                 goto Exit;
               continue;
@@ -183,7 +183,7 @@
             v_middle.x = ( v_control.x + vec.x ) / 2;
             v_middle.y = ( v_control.y + vec.y ) / 2;
 
-            error = interface->conic_to( &v_control, &v_middle, user );
+            error = func_interface->conic_to( &v_control, &v_middle, user );
             if ( error )
               goto Exit;
 
@@ -191,7 +191,7 @@
             goto Do_Conic;
           }
 
-          error = interface->conic_to( &v_control, &v_start, user );
+          error = func_interface->conic_to( &v_control, &v_start, user );
           goto Close;
 
         default:  /* FT_Curve_Tag_Cubic */
@@ -217,13 +217,13 @@
               vec.x = SCALED( point->x );
               vec.y = SCALED( point->y );
 
-              error = interface->cubic_to( &vec1, &vec2, &vec, user );
+              error = func_interface->cubic_to( &vec1, &vec2, &vec, user );
               if ( error )
                 goto Exit;
               continue;
             }
 
-            error = interface->cubic_to( &vec1, &vec2, &v_start, user );
+            error = func_interface->cubic_to( &vec1, &vec2, &v_start, user );
             goto Close;
           }
         }
@@ -230,7 +230,7 @@
       }
 
       /* close the contour with a line segment */
-      error = interface->line_to( &v_start, user );
+      error = func_interface->line_to( &v_start, user );
 
     Close:
       if ( error )
--- a/src/cff/cffdrivr.c
+++ b/src/cff/cffdrivr.c
@@ -437,7 +437,7 @@
 
   static FT_Module_Interface
   cff_get_interface( CFF_Driver   driver,
-                     const char*  interface )
+                     const char*  module_interface )
   {
     FT_Module  sfnt;
 
@@ -444,10 +444,10 @@
 
 #ifndef FT_CONFIG_OPTION_NO_GLYPH_NAMES
 
-    if ( ft_strcmp( (const char*)interface, "glyph_name" ) == 0 )
+    if ( ft_strcmp( (const char*)module_interface, "glyph_name" ) == 0 )
       return (FT_Module_Interface)cff_get_glyph_name;
 
-    if ( ft_strcmp( (const char*)interface, "name_index" ) == 0 )
+    if ( ft_strcmp( (const char*)module_interface, "name_index" ) == 0 )
       return (FT_Module_Interface)cff_get_name_index;
 
 #endif
@@ -455,7 +455,7 @@
     /* we simply pass our request to the `sfnt' module */
     sfnt = FT_Get_Module( driver->root.root.library, "sfnt" );
 
-    return sfnt ? sfnt->clazz->get_interface( sfnt, interface ) : 0;
+    return sfnt ? sfnt->clazz->get_interface( sfnt, module_interface ) : 0;
   }
 
 
--- a/src/cff/cffload.c
+++ b/src/cff/cffload.c
@@ -1313,7 +1313,7 @@
   FT_LOCAL_DEF( FT_String* )
   CFF_Get_String( CFF_Index        idx,
                   FT_UInt          sid,
-                  PSNames_Service  interface )
+                  PSNames_Service  psnames_interface )
   {
     /* if it is not a standard string, return it */
     if ( sid > 390 )
@@ -1322,7 +1322,7 @@
     /* that's a standard string, fetch a copy from the PSName module */
     {
       FT_String*   name       = 0;
-      const char*  adobe_name = interface->adobe_std_strings( sid );
+      const char*  adobe_name = psnames_interface->adobe_std_strings( sid );
       FT_UInt      len;
 
 
--- a/src/cff/cffload.h
+++ b/src/cff/cffload.h
@@ -38,7 +38,7 @@
   FT_LOCAL( FT_String* )
   CFF_Get_String( CFF_Index        idx,
                   FT_UInt          sid,
-                  PSNames_Service  interface );
+                  PSNames_Service  psnames_interface );
 
 
   FT_LOCAL( FT_Error )
--- a/src/cid/cidriver.c
+++ b/src/cid/cidriver.c
@@ -51,12 +51,12 @@
 
   static FT_Module_Interface
   CID_Get_Interface( FT_Driver         driver,
-                     const FT_String*  interface )
+                     const FT_String*  cid_interface )
   {
     FT_UNUSED( driver );
-    FT_UNUSED( interface );
+    FT_UNUSED( cid_interface );
 
-    if ( ft_strcmp( (const char*)interface, "postscript_name" ) == 0 )
+    if ( ft_strcmp( (const char*)cid_interface, "postscript_name" ) == 0 )
       return (FT_Module_Interface)cid_get_postscript_name;
 
     return 0;
--- a/src/sfnt/sfdriver.c
+++ b/src/sfnt/sfdriver.c
@@ -195,19 +195,19 @@
 
   FT_CALLBACK_DEF( FT_Module_Interface )
   SFNT_Get_Interface( FT_Module    module,
-                      const char*  interface )
+                      const char*  module_interface )
   {
     FT_UNUSED( module );
 
-    if ( ft_strcmp( interface, "get_sfnt" ) == 0 )
+    if ( ft_strcmp( module_interface, "get_sfnt" ) == 0 )
       return (FT_Module_Interface)get_sfnt_table;
 
 #ifdef TT_CONFIG_OPTION_POSTSCRIPT_NAMES
-    if ( ft_strcmp( interface, "glyph_name" ) == 0 )
+    if ( ft_strcmp( module_interface, "glyph_name" ) == 0 )
       return (FT_Module_Interface)get_sfnt_glyph_name;
 #endif
 
-    if ( ft_strcmp( interface, "postscript_name" ) == 0 )
+    if ( ft_strcmp( module_interface, "postscript_name" ) == 0 )
       return (FT_Module_Interface)get_sfnt_postscript_name;
 
     return 0;
--- a/src/truetype/ttdriver.c
+++ b/src/truetype/ttdriver.c
@@ -455,7 +455,7 @@
 
   static FT_Module_Interface
   tt_get_interface( TT_Driver    driver,
-                    const char*  interface )
+                    const char*  tt_interface )
   {
     FT_Module     sfntd = FT_Get_Module( driver->root.root.library,
                                          "sfnt" );
@@ -467,7 +467,7 @@
     {
       sfnt = (SFNT_Service)( sfntd->clazz->module_interface );
       if ( sfnt )
-        return sfnt->get_interface( FT_MODULE( driver ), interface );
+        return sfnt->get_interface( FT_MODULE( driver ), tt_interface );
     }
 
     return 0;
--- a/include/freetype/ftoutln.h
+++ b/include/freetype/ftoutln.h
@@ -5,7 +5,7 @@
 /*    Support for the FT_Outline type used to store glyph shapes of        */
 /*    most scalable font formats (specification).                          */
 /*                                                                         */
-/*  Copyright 1996-2001 by                                                 */
+/*  Copyright 1996-2001, 2002 by                                           */
 /*  David Turner, Robert Wilhelm, and Werner Lemberg.                      */
 /*                                                                         */
 /*  This file is part of the FreeType project, and may only be used,       */
@@ -83,15 +83,17 @@
   /*    of new contours in the outline.                                    */
   /*                                                                       */
   /* <Input>                                                               */
-  /*    outline   :: A pointer to the source target.                       */
+  /*    outline        :: A pointer to the source target.                  */
   /*                                                                       */
   /*    interface :: A table of `emitters', i.e,. function pointers called */
   /*                 during decomposition to indicate path operations.     */
   /*                                                                       */
   /* <InOut>                                                               */
-  /*    user      :: A typeless pointer which is passed to each emitter    */
-  /*                 during the decomposition.  It can be used to store    */
-  /*                 the state during the decomposition.                   */
+  /*    user           :: A typeless pointer which is passed to each       */
+  /*                      emitter during the decomposition.  It can be     */
+  /*                      used to store the state during the               */
+  /*                      decomposition.                                   */
   /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means sucess.                              */
@@ -98,7 +100,7 @@
   /*                                                                       */
   FT_EXPORT( FT_Error )
   FT_Outline_Decompose( FT_Outline*              outline,
-                        const FT_Outline_Funcs*  interface,
+                        const FT_Outline_Funcs*  func_interface,
                         void*                    user );
 
 
@@ -83,15 +83,17 @@
   /*                                                                       */
-  /*    interface :: A table of `emitters', i.e,. function pointers called */
-  /*                 during decomposition to indicate path operations.     */
+  /*    func_interface :: A table of `emitters', i.e,. function pointers   */
+  /*                      called during decomposition to indicate path     */
+  /*                      operations.                                      */
   /*                                                                       */
   /* <InOut>                                                               */
--- a/src/smooth/ftgrays.c
+++ b/src/smooth/ftgrays.c
@@ -1544,14 +1544,16 @@
   /*    of new contours in the outline.                                    */
   /*                                                                       */
   /* <Input>                                                               */
-  /*    outline   :: A pointer to the source target.                       */
+  /*    outline        :: A pointer to the source target.                  */
   /*                                                                       */
   /*    interface :: A table of `emitters', i.e,. function pointers called */
   /*                 during decomposition to indicate path operations.     */
   /*                                                                       */
-  /*    user      :: A typeless pointer which is passed to each emitter    */
-  /*                 during the decomposition.  It can be used to store    */
-  /*                 the state during the decomposition.                   */
+  /*    user           :: A typeless pointer which is passed to each       */
+  /*                      emitter during the decomposition.  It can be     */
+  /*                      used to store the state during the               */
+  /*                      decomposition.                                   */
   /*                                                                       */
   /* <Return>                                                              */
   /*    Error code.  0 means sucess.                                       */
@@ -1558,7 +1560,7 @@
   /*                                                                       */
   static
   int  FT_Outline_Decompose( FT_Outline*              outline,
-                             const FT_Outline_Funcs*  interface,
+                             const FT_Outline_Funcs*  func_interface,
                              void*                    user )
   {
 #undef SCALED
@@ -1582,8 +1584,8 @@
     char    tag;       /* current point's state           */
 
 #if 0
-    int     shift = interface->shift;
-    FT_Pos  delta = interface->delta;
+    int     shift = func_interface->shift;
+    FT_Pos  delta = func_interface->delta;
 #endif
 
 
@@ -1637,7 +1639,7 @@
         tags--;
       }
 
-      error = interface->move_to( &v_start, user );
+      error = func_interface->move_to( &v_start, user );
       if ( error )
         goto Exit;
 
@@ -1657,7 +1659,7 @@
             vec.x = SCALED( point->x );
             vec.y = SCALED( point->y );
 
-            error = interface->line_to( &vec, user );
+            error = func_interface->line_to( &vec, user );
             if ( error )
               goto Exit;
             continue;
@@ -1684,7 +1686,7 @@
 
               if ( tag == FT_Curve_Tag_On )
               {
-                error = interface->conic_to( &v_control, &vec, user );
+                error = func_interface->conic_to( &v_control, &vec, user );
                 if ( error )
                   goto Exit;
                 continue;
@@ -1696,7 +1698,7 @@
               v_middle.x = ( v_control.x + vec.x ) / 2;
               v_middle.y = ( v_control.y + vec.y ) / 2;
 
-              error = interface->conic_to( &v_control, &v_middle, user );
+              error = func_interface->conic_to( &v_control, &v_middle, user );
               if ( error )
                 goto Exit;
 
@@ -1704,7 +1706,7 @@
               goto Do_Conic;
             }
 
-            error = interface->conic_to( &v_control, &v_start, user );
+            error = func_interface->conic_to( &v_control, &v_start, user );
             goto Close;
           }
 
@@ -1731,13 +1733,13 @@
               vec.x = SCALED( point->x );
               vec.y = SCALED( point->y );
 
-              error = interface->cubic_to( &vec1, &vec2, &vec, user );
+              error = func_interface->cubic_to( &vec1, &vec2, &vec, user );
               if ( error )
                 goto Exit;
               continue;
             }
 
-            error = interface->cubic_to( &vec1, &vec2, &v_start, user );
+            error = func_interface->cubic_to( &vec1, &vec2, &v_start, user );
             goto Close;
           }
         }
@@ -1744,7 +1746,7 @@
       }
 
       /* close the contour with a line segment */
-      error = interface->line_to( &v_start, user );
+      error = func_interface->line_to( &v_start, user );
 
    Close:
       if ( error )
@@ -1776,7 +1778,7 @@
   gray_convert_glyph_inner( RAS_ARG )
   {
     static
-    const FT_Outline_Funcs  interface =
+    const FT_Outline_Funcs  func_interface =
     {
       (FT_Outline_MoveTo_Func) gray_move_to,
       (FT_Outline_LineTo_Func) gray_line_to,
@@ -1790,7 +1792,7 @@
 
     if ( setjmp( ras.jump_buffer ) == 0 )
     {
-      error = FT_Outline_Decompose( &ras.outline, &interface, &ras );
+      error = FT_Outline_Decompose( &ras.outline, &func_interface, &ras );
       gray_record_cell( RAS_VAR );
     }
     else
@@ -1881,7 +1883,7 @@
 #if 1
         error = gray_convert_glyph_inner( RAS_VAR );
 #else
-        error = FT_Outline_Decompose( outline, &interface, &ras ) ||
+        error = FT_Outline_Decompose( outline, &func_interface, &ras ) ||
                 gray_record_cell( RAS_VAR );
 #endif
 
@@ -1544,14 +1544,16 @@
   /*                                                                       */
-  /*    interface :: A table of `emitters', i.e,. function pointers called */
-  /*                 during decomposition to indicate path operations.     */
+  /*    func_interface :: A table of `emitters', i.e,. function pointers   */
+  /*                      called during decomposition to indicate path     */
+  /*                      operations.                                      */
   /*                                                                       */
--- a/src/type1/t1driver.c
+++ b/src/type1/t1driver.c
@@ -128,11 +128,11 @@
   /*     PostScript name of a given glyph index).                          */
   /*                                                                       */
   /* <InOut>                                                               */
-  /*    driver    :: A handle to a driver object.                          */
+  /*    driver       :: A handle to a driver object.                       */
   /*                                                                       */
   /* <Input>                                                               */
   /*    interface :: A string designing the interface.  Examples are       */
   /*                 `sfnt', `post_names', `charmaps', etc.                */
   /*                                                                       */
   /* <Return>                                                              */
   /*    A typeless pointer to the extension's interface (normally a table  */
@@ -142,28 +142,28 @@
   /*                                                                       */
   static FT_Module_Interface
   Get_Interface( FT_Driver         driver,
-                 const FT_String*  interface )
+                 const FT_String*  t1_interface )
   {
     FT_UNUSED( driver );
-    FT_UNUSED( interface );
+    FT_UNUSED( t1_interface );
 
-    if ( ft_strcmp( (const char*)interface, "glyph_name" ) == 0 )
+    if ( ft_strcmp( (const char*)t1_interface, "glyph_name" ) == 0 )
       return (FT_Module_Interface)t1_get_glyph_name;
 
-    if ( ft_strcmp( (const char*)interface, "name_index" ) == 0 )
+    if ( ft_strcmp( (const char*)t1_interface, "name_index" ) == 0 )
       return (FT_Module_Interface)t1_get_name_index;
 
-    if ( ft_strcmp( (const char*)interface, "postscript_name" ) == 0 )
+    if ( ft_strcmp( (const char*)t1_interface, "postscript_name" ) == 0 )
       return (FT_Module_Interface)t1_get_ps_name;
 
 #ifndef T1_CONFIG_OPTION_NO_MM_SUPPORT
-    if ( ft_strcmp( (const char*)interface, "get_mm" ) == 0 )
+    if ( ft_strcmp( (const char*)t1_interface, "get_mm" ) == 0 )
       return (FT_Module_Interface)T1_Get_Multi_Master;
 
-    if ( ft_strcmp( (const char*)interface, "set_mm_design") == 0 )
+    if ( ft_strcmp( (const char*)t1_interface, "set_mm_design") == 0 )
       return (FT_Module_Interface)T1_Set_MM_Design;
 
-    if ( ft_strcmp( (const char*)interface, "set_mm_blend") == 0 )
+    if ( ft_strcmp( (const char*)t1_interface, "set_mm_blend") == 0 )
       return (FT_Module_Interface)T1_Set_MM_Blend;
 #endif
     return 0;
@@ -128,11 +128,11 @@
   /*                                                                       */
   /* <Input>                                                               */
-  /*    interface :: A string designing the interface.  Examples are       */
-  /*                 `sfnt', `post_names', `charmaps', etc.                */
+  /*    t1_interface :: A string designing the interface.  Examples are    */
+  /*                    `sfnt', `post_names', `charmaps', etc.             */
   /*                                                                       */
   /* <Return>                                                              */